ComponentTemplate
=================

.. currentmodule:: dash_component_template.template

.. autoclass:: ComponentTemplate
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ComponentTemplate.children
      ~ComponentTemplate.dash_component_info
      ~ComponentTemplate.layout
      ~ComponentTemplate.parent

   .. rubric:: Methods Summary

   .. autosummary::

      ~ComponentTemplate.set_wildcard_prop
      ~ComponentTemplate.setup_layout

   .. rubric:: Attributes Documentation

   .. autoattribute:: children
   .. autoattribute:: dash_component_info
   .. autoattribute:: layout
   .. autoattribute:: parent

   .. rubric:: Methods Documentation

   .. automethod:: set_wildcard_prop
   .. automethod:: setup_layout
